/*
 *      File HFN2FNT.C
 *      Font Converter(HFN format to DKBB format)
 *      '90.7.24 (Original by Lim, I.K.)
 *      '99.9.18 (Converted by Lee, S.M.)
 *
 *      Compiler : Turbo C 2.01 (or above), DJGPP V2.02
 *      Compile  : tcc hfn2fnt.c
 *                 gcc hfn2fnt.c -s -o hfn2fnt.exe
 */


#include <dir.h>
#include <dos.h>
#include <fcntl.h>
#include <io.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#ifdef __DJGPP__
#include <unistd.h>
#endif

#define HANSIZE 32

typedef unsigned char byte;

/* Hangul font buffers */

static byte HF1[8][19][HANSIZE];  /* 8 set */
static byte HF2[4][21][HANSIZE];  /* 4 set */
static byte HF3[4][27][HANSIZE];  /* 4 set */
static byte HFFILL[HANSIZE];      /* fill code */


int main(int argc, char *argv[])
{
    int handle, i;
    char hanfontfile[MAXPATH], dkbbfontfile[MAXPATH];
    char drive[MAXDRIVE], dir[MAXDIR];
    char name[MAXFILE], ext[MAXEXT];

    if (argc != 2) {
        fprintf(stderr, "Hangul font converter (11008 byte -> 11520 byte)\n");
        fprintf(stderr, "Usage: hfn2fnt hanfont[.hfn]\n");
        exit(EXIT_FAILURE);
    }
    if ((fnsplit(argv[1], drive, dir, name, ext) & WILDCARDS) != 0) {
        fprintf(stderr, "\nDon't use wildcards\n");
        exit(EXIT_FAILURE);
    }

    if (ext[0] == '\0') strcpy(ext, ".hfn");
    fnmerge(hanfontfile, drive, dir, name, ext);
    strcpy(ext, ".fnt");
    fnmerge(dkbbfontfile, drive, dir, name, ext);

    fprintf(stdout, "\nConverting %s (11008 byte) to %s (11520 byte)\n",
            hanfontfile, dkbbfontfile);

    handle = open(hanfontfile, O_RDONLY | O_BINARY);
    if (handle == -1) {
        fprintf(stderr, "\nFatal error: HAN Hangul font not found\n");
        exit(EXIT_FAILURE);
    }

    if (filelength(handle) != 11008) {
        fprintf(stderr, "\nFatal error: This file can not convert (only 11008 byte)\n");
        exit(EXIT_FAILURE);
    }

    read(handle, HF1, sizeof(HF1));
    read(handle, HF2, sizeof(HF2));
    read(handle, HF3, sizeof(HF3));

    close(handle);

    handle = _creat(dkbbfontfile, FA_ARCH);

    for (i = 0; i < 8; i++) {
        write(handle, HFFILL, sizeof(HFFILL));
        write(handle, HF1[i], sizeof(HF1[i]));
    }
    for (i = 0; i < 4; i++) {
        write(handle, HFFILL, sizeof(HFFILL));
        write(handle, HF2[i], sizeof(HF2[i]));
    }
    for (i = 0; i < 4; i++) {
        write(handle, HFFILL, sizeof(HFFILL));
        write(handle, HF3[i], sizeof(HF3[i]));
    }

    close(handle);

    return 0;
}
